@@ -17,7 +17,7 @@ CORS(app)
 _CALLS = 100
 _PERIOD = 60
 
-webbrowser.open('http://localhost:5000', new=2)
+webbrowser.open('http://127.0.0.1:5000', new=2)
 
 
 @app.route("/")
@@ -121,5 +121,6 @@ def serve_static_files(path):
 def main():
     app.run(host='127.0.0.1', port='5000')
 
+
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
